import 'package:flutter/material.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/l10n/extension.dart';
import 'package:mcomp_flutter_app/models/device/blinder_model.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/models/device/door_model.dart';
import 'package:mcomp_flutter_app/models/device/heating_model.dart';
import 'package:mcomp_flutter_app/models/device/light_model.dart';
import 'package:mcomp_flutter_app/models/device/recuperation_model.dart';
import 'package:mcomp_flutter_app/models/room_model.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/center_by_type/blinder/blinder_center_widget.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/center_by_type/light_center_widget.dart';

class DeviceCategoryModel {
  const DeviceCategoryModel({
    required this.title,
    required this.icon,
    required this.devices,
  });
  final String title;
  final IconData icon;
  final List<DeviceModel> devices;
}

class DeviceWidgetParams {
  DeviceWidgetParams({
    required this.icon,
    required this.widget,
  });
  IconData icon;
  Widget widget;
}

class DeviceHelper {
  List<RoomModel> getRooms({required List<DeviceModel> devices}) {
    final rooms = <RoomModel>[];
    final roomIds = <String>[];
    for (final device in devices) {
      if (device.room != null) {
        if (roomIds.contains(device.room!.id)) continue;
        rooms.add(device.room!);
        roomIds.add(device.room!.id);
      }
    }
    return rooms;
  }

  List<DeviceCategoryModel?> getCategories({
    required BuildContext context,
    required List<DeviceModel> devices,
    required List<DeviceModel> favDevices,
  }) {
    final categories = <DeviceCategoryModel?>[];

    if (favDevices.isNotEmpty) {
      categories.add(
        DeviceCategoryModel(
          title: context.l10n.favorite_title,
          icon: ConstIcons.favorite,
          devices: favDevices,
        ),
      );
    }

    for (final device in devices) {
      var title = '';
      var icon = Icons.warning_outlined;
      switch (device.runtimeType) {
        case BlinderModel:
          title = context.l10n.blinder_type_title;
          icon = ConstIcons.deviceBlinder;
          break;
        case DoorModel:
          title = context.l10n.door_type_title;
          icon = ConstIcons.deviceDoor;
          break;
        case HeatingModel:
          title = context.l10n.heating_type_title;
          icon = ConstIcons.deviceHeating;
          break;
        case LightModel:
          title = context.l10n.light_type_title;
          icon = ConstIcons.deviceLight;
          break;
        case RecuperationModel:
          title = context.l10n.recuperation_type_title;
          icon = ConstIcons.deviceRecuperation;
          break;
      }
      if (title == '') continue;

      final category = categories.firstWhere(
        (element) => element?.title == title,
        orElse: () => null,
      );

      if (category != null) {
        category.devices.add(device);
      } else {
        final newCategory =
            DeviceCategoryModel(title: title, icon: icon, devices: [device]);
        categories.add(newCategory);
      }
    }
    return categories;
  }

  DeviceWidgetParams getWidgetParams({
    required DeviceModel device,
  }) {
    final widgetParams =
        DeviceWidgetParams(icon: Icons.warning_outlined, widget: Container());
    switch (device.runtimeType) {
      case BlinderModel:
        widgetParams.icon = ConstIcons.deviceBlinder;
        widgetParams.widget = BlinderCenterWidget(
          deviceId: device.id,
        );
        break;
      case DoorModel:
        widgetParams.icon = ConstIcons.deviceDoor;
        break;
      case HeatingModel:
        widgetParams.icon = ConstIcons.deviceHeating;
        break;
      case LightModel:
        widgetParams.icon = ConstIcons.deviceLight;
        widgetParams.widget = LightCenterWidget(
          deviceId: device.id,
        );
        break;
      case RecuperationModel:
        widgetParams.icon = ConstIcons.deviceRecuperation;
        break;
    }
    return widgetParams;
  }
}
