import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_fimber/flutter_fimber.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:mcomp_flutter_app/helpers/custom_app_theme.dart';
import 'package:mcomp_flutter_app/helpers/device_type.dart';
import 'package:mcomp_flutter_app/screens/detail_screen.dart';
import 'package:mcomp_flutter_app/screens/error_screen.dart';
import 'package:mcomp_flutter_app/screens/main_screen.dart';
import 'package:url_strategy/url_strategy.dart';

void main() {
  _setupFimber();
  setPathUrlStrategy();
  runApp(
    const ProviderScope(
      child: MyApp(),
    ),
  );
}

void _setupFimber() {
  if (kDebugMode || kProfileMode) {
    Fimber.plantTree(
      CustomFormatTree(
        logFormat:
            '${CustomFormatTree.timeStampToken} | ${CustomFormatTree.messageToken}',
        useColors: true,
        logLevels: ['V', 'D', 'I', 'W', 'E'],
      ),
    );
  }
}

final GoRouter _router = GoRouter(
  routes: <RouteBase>[
    GoRoute(
      path: '/',
      builder: (BuildContext context, GoRouterState state) {
        return const MainScreen();
      },
      routes: <RouteBase>[
        GoRoute(
          path: 'detail',
          builder: (BuildContext context, GoRouterState state) {
            final content = state.extra as DetailScreenContent;
            return DetailScreen(
              content: content,
            );
          },
          redirect: (context, state) {
            if (state.extra == null) return '/';
            return null;
          },
        ),
      ],
    ),
  ],
  errorBuilder: (context, state) => const ErrorScreen(),
);

class MyApp extends ConsumerWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final densityAmt = DeviceType.isMobile ? 0.0 : -1.0;
    final density = VisualDensity(horizontal: densityAmt, vertical: densityAmt);

    return MaterialApp.router(
      title: 'MCOMP app',
      localizationsDelegates: AppLocalizations.localizationsDelegates,
      supportedLocales: AppLocalizations.supportedLocales,
      theme: CustomAppTheme.getLightTheme(visualDensity: density),
      darkTheme: CustomAppTheme.getDarkTheme(visualDensity: density),
      themeMode: ThemeMode.system,
      routerConfig: _router,
    );
  }
}
