import 'package:json_annotation/json_annotation.dart';
import 'package:mcomp_flutter_app/models/device/blinder_model.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/models/device/device_model_type.dart';
import 'package:mcomp_flutter_app/models/device/door_model.dart';
import 'package:mcomp_flutter_app/models/device/heating_model.dart';
import 'package:mcomp_flutter_app/models/device/light_model.dart';
import 'package:mcomp_flutter_app/models/device/recuperation_model.dart';

part 'home_plc_model.g.dart';

@JsonSerializable(explicitToJson: true)
class HomePLCModel {
  HomePLCModel({
    required this.id,
    required this.name,
    required this.plcIP,
    required this.devices,
  });

  factory HomePLCModel.fromJson(Map<String, dynamic> json) =>
      _$HomePLCModelFromJson(json);
  final String id;
  final String name;
  final String plcIP;
  @JsonKey(fromJson: _devicesFromJson)
  final List<DeviceModel> devices;

  Map<String, dynamic> toJson() => _$HomePLCModelToJson(this);

  static List<DeviceModel> _devicesFromJson(List<dynamic> devices) {
    final typedDevices = <DeviceModel>[];
    for (final device in devices) {
      try {
        final typedDevice = DoorModel.fromJson(device as Map<String, dynamic>);
        if (typedDevice.deviceType == DeviceModelType.door) {
          typedDevices.add(typedDevice);
        }
      } catch (e) {
        // Not a type of DoorModel
      }
      try {
        final typedDevice =
            BlinderModel.fromJson(device as Map<String, dynamic>);
        if (typedDevice.deviceType == DeviceModelType.blinder) {
          typedDevices.add(typedDevice);
        }
      } catch (e) {
        // Not a type of BlinderModel
      }
      try {
        final typedDevice =
            HeatingModel.fromJson(device as Map<String, dynamic>);
        if (typedDevice.deviceType == DeviceModelType.heating) {
          typedDevices.add(typedDevice);
        }
      } catch (e) {
        // Not a type of HeatingModel
      }
      try {
        final typedDevice = LightModel.fromJson(device as Map<String, dynamic>);
        if (typedDevice.deviceType == DeviceModelType.light) {
          typedDevices.add(typedDevice);
        }
      } catch (e) {
        // Not a type of LightModel
      }
      try {
        final typedDevice =
            RecuperationModel.fromJson(device as Map<String, dynamic>);
        if (typedDevice.deviceType == DeviceModelType.recuperation) {
          typedDevices.add(typedDevice);
        }
      } catch (e) {
        // Not a type of RecuperationModel
      }
    }
    return typedDevices;
  }
}
