import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/helpers/device_type.dart';
import 'package:mcomp_flutter_app/models/home_plc_model.dart';
import 'package:mcomp_flutter_app/widgets/select_home_widget.dart';
import 'package:shared_preferences/shared_preferences.dart';

part 'current_home_provider.freezed.dart';

@freezed
class CurrentHomeState with _$CurrentHomeState {
  factory CurrentHomeState({
    @Default(null) HomePLCModel? currentHome,
    @Default(true) bool isLoading,
  }) = _CurrentHomeState;
}

final currentHomeProvider =
    StateNotifierProvider<CurrentHomeNotifier, CurrentHomeState>(
  (ref) => CurrentHomeNotifier(),
);

class CurrentHomeNotifier extends StateNotifier<CurrentHomeState> {
  CurrentHomeNotifier() : super(CurrentHomeState());
  bool selectHomeWidgetIsVisible = false;

  Future<void> getCurrentHome({
    required BuildContext ctx,
    required WidgetRef ref,
    required List<HomePLCModel> userHomes,
  }) async {
    final prefs = await SharedPreferences.getInstance();
    final currentHomeId = prefs.getString(Consts.currentHomeIdKey);

    for (final userHome in userHomes) {
      if (userHome.id == currentHomeId) {
        state = state.copyWith(
          currentHome: userHome,
          isLoading: false,
        );
        return;
      }
    }
    if (!mounted || userHomes.isEmpty || selectHomeWidgetIsVisible) return;
    state = state.copyWith(
      isLoading: false,
    );
    if (!DeviceType.isSmallScreen(ctx)) return;
    selectHomeWidget(context: ctx, ref: ref, userHomes: userHomes);
    selectHomeWidgetIsVisible = true;
  }

  Future<void> setCurrentHome({required HomePLCModel userHome}) async {
    final prefs = await SharedPreferences.getInstance();
    await prefs.setString(Consts.currentHomeIdKey, userHome.id);
    state = state.copyWith(
      currentHome: userHome,
    );
  }
}
