import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:shared_preferences/shared_preferences.dart';

part 'favorites_provider.freezed.dart';

@freezed
class FavoritesState with _$FavoritesState {
  factory FavoritesState({
    @Default([]) List<String> deviceIDs,
    @Default(true) bool isLoading,
  }) = _FavoritesState;
}

final favoritesProvider =
    StateNotifierProvider<FavoritesNotifier, FavoritesState>(
  (ref) => FavoritesNotifier(),
);

class FavoritesNotifier extends StateNotifier<FavoritesState> {
  FavoritesNotifier() : super(FavoritesState()) {
    _getFavoriteDeviceIDs();
  }

  Future<void> _getFavoriteDeviceIDs() async {
    final prefs = await SharedPreferences.getInstance();
    final deviceIDs = prefs.getStringList(Consts.favoriteDevicesKey);
    state = state.copyWith(deviceIDs: deviceIDs ?? [], isLoading: false);
  }

  Future<void> toogleDevice({required String deviceId}) async {
    final deviceIDs = <String>[...state.deviceIDs];

    if (deviceIDs.contains(deviceId)) {
      deviceIDs.remove(deviceId);
    } else {
      deviceIDs.add(deviceId);
    }
    state = state.copyWith(deviceIDs: deviceIDs);
    final prefs = await SharedPreferences.getInstance();
    await prefs.setStringList(Consts.favoriteDevicesKey, deviceIDs);
  }
}
