import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:mcomp_flutter_app/models/user_model.dart';
import 'package:mcomp_flutter_app/providers/current_home_provider.dart';

part 'user_config_provider.freezed.dart';

@freezed
class UserConfigState with _$UserConfigState {
  factory UserConfigState({
    @Default(null) UserModel? userConfig,
    @Default(true) bool isLoading,
  }) = _UserConfigState;
}

final userConfigProvider =
    StateNotifierProvider<UserConfigNotifier, UserConfigState>(
  (ref) => UserConfigNotifier(ref: ref),
);

class UserConfigNotifier extends StateNotifier<UserConfigState> {
  UserConfigNotifier({required this.ref}) : super(UserConfigState());
  final Ref ref;

  Future<void> parseDummyConfig({
    required BuildContext ctx,
    required WidgetRef widgetRef,
  }) async {
    if (state.userConfig != null) return;
    Future.delayed(const Duration(milliseconds: 2000), () async {
      final data = await DefaultAssetBundle.of(ctx)
          .loadString('assets/dummy_user_config.json');
      final userConfig =
          UserModel.fromJson(jsonDecode(data) as Map<String, dynamic>);
      state = state.copyWith(
        userConfig: userConfig,
        isLoading: false,
      );
      if (!mounted) return;
      await ref.read(currentHomeProvider.notifier).getCurrentHome(
            ctx: ctx,
            ref: widgetRef,
            userHomes: userConfig.homePLCs,
          );
    });
  }
}
