import 'dart:convert';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/web_socket_helper.dart';
import 'package:mcomp_flutter_app/models/plc_models/plc_model_list.dart';
import 'package:mcomp_flutter_app/providers/current_home_provider.dart';

final webSocketProvider =
    StreamProvider.autoDispose<Map<String?, Map<String, dynamic>>>(
        (ref) async* {
  final currentHome = ref.watch(currentHomeProvider).currentHome;
  final homeIsLoading = ref.watch(currentHomeProvider).isLoading;
  final devicesToProcess = <String?, Map<String, dynamic>>{};

  if (homeIsLoading) return;
  final channel = WebSocketHelper().connectWebSocket(currentHome?.plcIP);
  ref.onDispose(() => WebSocketHelper().closeWebSocket());

  await for (final value in channel.stream) {
    final listMap = jsonDecode(value.toString()) as Map<String, dynamic>;
    final list = PlcModelList.fromJson(listMap);

    list.list?.forEach((element) {
      devicesToProcess[element.id] = element.props;
    });

    list.diff?.forEach((element) {
      devicesToProcess[element.id] = element.props;
    });

    yield devicesToProcess;
  }
});
