import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/helpers/device_type.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/screens/screen_stack_template.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/device_widget.dart';
import 'package:mcomp_flutter_app/widgets/screen_spacer_line_widget.dart';
import 'package:mcomp_flutter_app/widgets/title_text_widget.dart';

class DetailScreenContent {
  const DetailScreenContent({required this.title, required this.devices});
  final String title;
  final List<DeviceModel> devices;
}

class DetailScreen extends ConsumerWidget {
  const DetailScreen({required this.content, super.key});

  final DetailScreenContent content;

  List<DeviceWidget> _getDevicesWidgets({required double screenWidth}) {
    final deviceWidgets = <DeviceWidget>[];

    // infinityWidth < (deviceWidgetWidth + <wrap horizontal padding>) * 2 + <wrap spacing>
    final infinityWidth = screenWidth < (Consts.deviceWidgetWidth + 8) * 2 + 8;

    for (final device in content.devices) {
      deviceWidgets.add(
        DeviceWidget(
          device: device,
          widgetWidth: infinityWidth ? double.infinity : null,
        ),
      );
    }
    return deviceWidgets;
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final screenHeight = MediaQuery.of(context).size.height;
    final screenWidth = MediaQuery.of(context).size.width;

    final deviceWidgets = _getDevicesWidgets(screenWidth: screenWidth);

    return ScreenStackTemplate(
      title: content.title,
      bodyWidget: SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            SizedBox(
              height: DeviceType.isSmallScreen(context)
                  ? screenHeight / Consts.screenSpacerCoeff
                  : Consts.screenHeaderSpacer,
              child: const ScreenSpacerLineWidget(),
            ),
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: Align(
                alignment: Alignment.topLeft,
                child: TitleTextWidget(
                  text: content.title,
                  style: Theme.of(context).textTheme.headlineMedium,
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8.0),
              child: Wrap(
                direction: Axis.horizontal,
                alignment: deviceWidgets.length == 1 ||
                        !DeviceType.isSmallScreen(context)
                    ? WrapAlignment.start
                    : WrapAlignment.spaceEvenly,
                spacing: 8,
                runSpacing: 8,
                children: deviceWidgets,
              ),
            ),
            Consts.screenFooterHeight
          ],
        ),
      ),
    );
  }
}
