import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/helpers/device_helper.dart';
import 'package:mcomp_flutter_app/helpers/device_type.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/providers/current_home_provider.dart';
import 'package:mcomp_flutter_app/providers/favorites_provider.dart';
import 'package:mcomp_flutter_app/providers/user_config_provider.dart';
import 'package:mcomp_flutter_app/screens/screen_stack_template.dart';
import 'package:mcomp_flutter_app/widgets/devices_chips_widget.dart';
import 'package:mcomp_flutter_app/widgets/home_title_widget.dart';
import 'package:mcomp_flutter_app/widgets/platform_activity_indicator.dart';
import 'package:mcomp_flutter_app/widgets/room_preview_widget.dart';
import 'package:mcomp_flutter_app/widgets/screen_spacer_line_widget.dart';
import 'package:mcomp_flutter_app/widgets/select_home_widget.dart';

class MainScreen extends ConsumerWidget {
  const MainScreen({super.key});

  List<Widget> getRoomsWidgets({required List<DeviceModel> devices}) {
    final roomWidgets = <Widget>[];
    final rooms = DeviceHelper().getRooms(devices: devices);
    for (final room in rooms) {
      roomWidgets.add(
        RoomPreviewWidget(
          devices: devices,
          room: room,
        ),
      );
    }
    return roomWidgets;
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final userConfig = ref.watch(userConfigProvider).userConfig;
    final cfgIsLoading = ref.watch(userConfigProvider).isLoading;

    final currentHome = ref.watch(currentHomeProvider).currentHome;
    final homeIsLoading = ref.watch(currentHomeProvider).isLoading;

    final favIsLoading = ref.watch(favoritesProvider).isLoading;

    final screenHeight = MediaQuery.of(context).size.height;

    unawaited(
      ref
          .read(userConfigProvider.notifier)
          .parseDummyConfig(ctx: context, widgetRef: ref),
    );

    return ScreenStackTemplate(
      title: currentHome?.name ?? '',
      bodyWidget: cfgIsLoading || homeIsLoading || favIsLoading
          ? const Center(
              child: PlatformActivityIndicator(),
            )
          : currentHome == null
              ? Center(
                  child: InkWell(
                    child: const Icon(
                      Icons.home_outlined,
                      size: 72,
                    ),
                    onTap: () {
                      selectHomeWidget(
                        context: context,
                        ref: ref,
                        userHomes: userConfig?.homePLCs ?? [],
                      );
                    },
                  ),
                )
              : SingleChildScrollView(
                  child: Column(
                    children: [
                      SizedBox(
                        height: DeviceType.isSmallScreen(context)
                            ? screenHeight / Consts.screenSpacerCoeff
                            : Consts.screenHeaderSpacer,
                        child: const ScreenSpacerLineWidget(),
                      ),
                      HomeTitleWidget(
                        title: currentHome.name,
                        homePressed: () {
                          selectHomeWidget(
                            context: context,
                            ref: ref,
                            userHomes: userConfig?.homePLCs ?? [],
                          );
                        },
                        menuPressed: () {},
                      ),
                      DevicesChipsWidget(
                        devices: currentHome.devices,
                      ),
                      ...getRoomsWidgets(devices: currentHome.devices),
                      Consts.screenFooterHeight
                    ],
                  ),
                ),
    );
  }
}
