import 'package:flutter/material.dart';
import 'package:mcomp_flutter_app/helpers/device_type.dart';
import 'package:mcomp_flutter_app/widgets/left_menu/left_menu_widget.dart';

class ScreenStackTemplate extends StatelessWidget {
  const ScreenStackTemplate({
    required this.title,
    required this.bodyWidget,
    super.key,
  });

  final String title;
  final Widget bodyWidget;

  @override
  Widget build(BuildContext context) {
    final isSmallScreen = DeviceType.isSmallScreen(context);

    return Stack(
      children: [
        Container(
          height: double.infinity,
          color: Theme.of(context).colorScheme.primary,
        ),
        SafeArea(
          child: Scaffold(
            appBar: isSmallScreen
                ? AppBar(
                    title: Text(
                      title,
                      style: Theme.of(context).textTheme.titleMedium,
                    ),
                  )
                : null,
            body: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                if (!isSmallScreen) const LeftMenuWidget(),
                if (!isSmallScreen)
                  Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Container(
                      height: double.infinity,
                      width: 1,
                      color: Theme.of(context).colorScheme.secondary,
                    ),
                  ),
                Expanded(child: bodyWidget),
              ],
            ),
          ),
        ),
      ],
    );
  }
}
