import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/web_socket_helper.dart';
import 'package:mcomp_flutter_app/models/plc_models/plc_model_blinder.dart';
import 'package:mcomp_flutter_app/providers/web_socket_provider.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/center_by_type/blinder/blinder_control_widget.dart';
import 'package:mcomp_flutter_app/widgets/platform_activity_indicator.dart';

class BlinderCenterWidget extends ConsumerWidget {
  const BlinderCenterWidget({required this.deviceId, super.key});

  final String deviceId;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final message = ref.watch(webSocketProvider);
    PlcModelBlinder? blinder;

    return message.when(
      loading: () => const PlatformActivityIndicator(),
      error: (err, stack) => Text('Error: $err'),
      data: (devices) {
        blinder = PlcModelBlinder.fromJson(devices[deviceId] ?? {});

        if (blinder == null) return const PlatformActivityIndicator();

        return Padding(
          padding: const EdgeInsets.only(bottom: 8.0),
          child: OutlinedButton(
            onPressed: () {
              showBlinderControlWidget(context: context, blinder: blinder!)
                  .then((newValue) {
                blinder?.percentageW?.val = newValue;
                WebSocketHelper().wsUpdateDevice(deviceId, blinder!.toJson());
              });
            },
            child: Text(
              '${blinder?.percentageR?.val?.toInt().toString()}%',
              style: Theme.of(context).textTheme.labelMedium,
            ),
          ),
        );
      },
    );
  }
}
