import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/web_socket_helper.dart';
import 'package:mcomp_flutter_app/models/plc_models/plc_model_light.dart';
import 'package:mcomp_flutter_app/providers/web_socket_provider.dart';
import 'package:mcomp_flutter_app/widgets/platform_activity_indicator.dart';

class LightCenterWidget extends ConsumerWidget {
  const LightCenterWidget({required this.deviceId, super.key});

  final String deviceId;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final message = ref.watch(webSocketProvider);
    PlcModelLight? light;

    return message.when(
      loading: () => const PlatformActivityIndicator(),
      error: (err, stack) => Text('Error: $err'),
      data: (devices) {
        light = PlcModelLight.fromJson(devices[deviceId] ?? {});

        if (light == null) return const PlatformActivityIndicator();

        return Padding(
          padding: const EdgeInsets.only(bottom: 8.0),
          child: OutlinedButton(
            onPressed: () {
              final state = light?.isOnRW?.val;
              if (state != null) {
                light?.isOnRW?.val = state ? false : true;
                WebSocketHelper().wsUpdateDevice(deviceId, light!.toJson());
              }
            },
            child: Text(
              light?.isOnRW?.val ?? false ? 'zhasnout' : 'rožnout',
              style: Theme.of(context).textTheme.labelMedium,
            ),
          ),
        );
      },
    );
  }
}
