import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/helpers/device_helper.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/providers/favorites_provider.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/device_footer_widget.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/device_header_widget.dart';

class DeviceWidget extends ConsumerWidget {
  const DeviceWidget({required this.device, this.widgetWidth, super.key});

  final double? widgetWidth;
  final DeviceModel device;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final deviceWidgetParams = DeviceHelper().getWidgetParams(device: device);
    final favDeviceIDs = ref.watch(favoritesProvider).deviceIDs;
    return SizedBox(
      width: widgetWidth ?? Consts.deviceWidgetWidth,
      height: Consts.deviceWidgetHeight,
      child: ClipRRect(
        borderRadius: BorderRadius.circular(Consts.borderRadius),
        child: Container(
          color: Theme.of(context).colorScheme.secondary,
          child: Stack(
            children: [
              Column(
                children: [
                  const Spacer(),
                  deviceWidgetParams.widget,
                  DeviceFooterWidget(
                    deviceName: device.name,
                    roomName: device.room?.name ?? '',
                  )
                ],
              ),
              DeviceHeaderWidget(
                deviceIconData: deviceWidgetParams.icon,
                favoriteIconData: favDeviceIDs.contains(device.id)
                    ? ConstIcons.favorite
                    : ConstIcons.notFavorite,
                favoritePressed: () {
                  ref
                      .read(favoritesProvider.notifier)
                      .toogleDevice(deviceId: device.id);
                },
              )
            ],
          ),
        ),
      ),
    );
  }
}
