import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/helpers/device_helper.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/providers/favorites_provider.dart';
import 'package:mcomp_flutter_app/screens/detail_screen.dart';

class DevicesChipsWidget extends ConsumerWidget {
  const DevicesChipsWidget({super.key, required this.devices});

  final List<DeviceModel> devices;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final favDeviceIDs = ref.watch(favoritesProvider).deviceIDs;
    final favDevices =
        devices.where((element) => favDeviceIDs.contains(element.id)).toList();
    final categories = DeviceHelper().getCategories(
      context: context,
      devices: devices,
      favDevices: favDevices,
    );
    return SizedBox(
      height: Consts.devicesChipsWidgetHeight,
      child: ListView.builder(
        scrollDirection: Axis.horizontal,
        itemCount: categories.length,
        itemBuilder: (BuildContext context, int index) {
          final isFirst = categories[index] == categories.first;
          final isLast = categories[index] == categories.last;
          return Padding(
            padding: isLast
                ? const EdgeInsets.only(left: 8.0, right: 16)
                : EdgeInsets.only(left: isFirst ? 16 : 8.0),
            child: ActionChip(
              avatar: Padding(
                padding: const EdgeInsets.only(left: 8.0),
                child: Icon(categories[index]?.icon),
              ),
              label: Padding(
                padding:
                    const EdgeInsets.only(top: 8.0, right: 8.0, bottom: 8.0),
                child: Text(
                  categories[index]?.title ?? '',
                  style: Theme.of(context).textTheme.labelMedium,
                ),
              ),
              shape: RoundedRectangleBorder(
                borderRadius:
                    BorderRadius.all(Radius.circular(Consts.borderRadius)),
              ),
              onPressed: () {
                final detailContent = DetailScreenContent(
                  title: categories[index]?.title ?? '',
                  devices: categories[index]?.devices ?? [],
                );
                context.push(
                  '/detail',
                  extra: detailContent,
                );
              },
            ),
          );
        },
      ),
    );
  }
}
