import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/models/room_model.dart';
import 'package:mcomp_flutter_app/screens/detail_screen.dart';
import 'package:mcomp_flutter_app/widgets/title_text_widget.dart';

class LeftMenuRoomItem extends ConsumerWidget {
  const LeftMenuRoomItem({
    required this.room,
    required this.devices,
    super.key,
  });

  final RoomModel room;
  final List<DeviceModel> devices;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final roomDevices =
        devices.where((element) => element.room?.id == room.id).toList();
    return Padding(
      padding: Consts.leftMenuCategoryPadding,
      child: FilledButton.tonalIcon(
        onPressed: () {
          final detailContent = DetailScreenContent(
            title: room.name,
            devices: roomDevices,
          );
          context.push(
            '/detail',
            extra: detailContent,
          );
        },
        style: Theme.of(context).textButtonTheme.style,
        label: TitleTextWidget(
          text: room.name,
          style: Theme.of(context).textTheme.labelMedium,
        ),
        icon: const Icon(Icons.space_dashboard_outlined),
      ),
    );
  }
}
