import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/device_helper.dart';
import 'package:mcomp_flutter_app/l10n/extension.dart';
import 'package:mcomp_flutter_app/providers/current_home_provider.dart';
import 'package:mcomp_flutter_app/providers/favorites_provider.dart';
import 'package:mcomp_flutter_app/providers/user_config_provider.dart';
import 'package:mcomp_flutter_app/widgets/left_menu/left_menu_category_item.dart';
import 'package:mcomp_flutter_app/widgets/left_menu/left_menu_home_item.dart';
import 'package:mcomp_flutter_app/widgets/left_menu/left_menu_room_item.dart';
import 'package:mcomp_flutter_app/widgets/title_text_widget.dart';

enum SectionWidgetType {
  homes,
  categories,
  rooms,
}

class LeftMenuSection extends ConsumerWidget {
  const LeftMenuSection({required this.forType, super.key});

  final SectionWidgetType forType;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final userConfig = ref.watch(userConfigProvider).userConfig;

    final currentHome = ref.watch(currentHomeProvider).currentHome;

    final favDeviceIDs = ref.watch(favoritesProvider).deviceIDs;
    final favDevices = currentHome?.devices
        .where((element) => favDeviceIDs.contains(element.id))
        .toList();

    var title = '';
    final widgets = <Widget>[];
    switch (forType) {
      case SectionWidgetType.homes:
        title = context.l10n.left_menu_homes_title;
        if (userConfig == null) break;
        for (final home in userConfig.homePLCs) {
          widgets.add(LeftMenuHomeItem(home: home));
        }
        break;
      case SectionWidgetType.categories:
        title = context.l10n.left_menu_devices_title;
        if (currentHome == null || favDevices == null) break;
        final categories = DeviceHelper().getCategories(
          context: context,
          devices: currentHome.devices,
          favDevices: favDevices,
        );
        for (final category in categories) {
          widgets.add(LeftMenuCategoryItem(category: category));
        }
        break;
      case SectionWidgetType.rooms:
        title = context.l10n.left_menu_rooms_title;
        if (currentHome == null) break;
        final rooms = DeviceHelper().getRooms(devices: currentHome.devices);
        for (final room in rooms) {
          widgets.add(
            LeftMenuRoomItem(
              room: room,
              devices: currentHome.devices,
            ),
          );
        }
        break;
    }
    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: [
        Padding(
          padding: const EdgeInsets.only(
            top: 16.0,
            left: 8.0,
            right: 8.0,
          ),
          child: TitleTextWidget(
            text: title,
            style: Theme.of(context).textTheme.titleSmall,
          ),
        ),
        ...widgets,
      ],
    );
  }
}
