import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/providers/current_home_provider.dart';
import 'package:mcomp_flutter_app/providers/favorites_provider.dart';
import 'package:mcomp_flutter_app/providers/user_config_provider.dart';
import 'package:mcomp_flutter_app/widgets/left_menu/left_menu_section.dart';
import 'package:mcomp_flutter_app/widgets/platform_activity_indicator.dart';

class LeftMenuWidget extends ConsumerWidget {
  const LeftMenuWidget({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final cfgIsLoading = ref.watch(userConfigProvider).isLoading;
    final homeIsLoading = ref.watch(currentHomeProvider).isLoading;
    final favIsLoading = ref.watch(favoritesProvider).isLoading;

    final screenWidth = MediaQuery.of(context).size.width;

    return Container(
      constraints: BoxConstraints(maxWidth: Consts.maxLeftMenuWidth),
      color: Theme.of(context).primaryColor,
      width: screenWidth / Consts.leftMenuWidthCoeff,
      child: cfgIsLoading || homeIsLoading || favIsLoading
          ? const Center(
              child: PlatformActivityIndicator(),
            )
          : SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  SizedBox(
                    height: Consts.screenHeaderSpacer,
                  ),
                  const LeftMenuSection(forType: SectionWidgetType.homes),
                  const LeftMenuSection(forType: SectionWidgetType.categories),
                  const LeftMenuSection(forType: SectionWidgetType.rooms),
                ],
              ),
            ),
    );
  }
}
