import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';
import 'package:mcomp_flutter_app/helpers/constants.dart';
import 'package:mcomp_flutter_app/models/device/device_model.dart';
import 'package:mcomp_flutter_app/models/room_model.dart';
import 'package:mcomp_flutter_app/screens/detail_screen.dart';
import 'package:mcomp_flutter_app/widgets/device_widget/device_widget.dart';
import 'package:mcomp_flutter_app/widgets/room_title_widget.dart';

class RoomPreviewWidget extends StatelessWidget {
  const RoomPreviewWidget({
    required this.devices,
    required this.room,
    super.key,
  });

  final List<DeviceModel> devices;
  final RoomModel room;

  @override
  Widget build(BuildContext context) {
    final roomDevices =
        devices.where((element) => element.room?.id == room.id).toList();
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.only(top: 8.0),
          child: RoomTitleWidget(
            title: room.name,
            onTap: () {
              final detailContent = DetailScreenContent(
                title: room.name,
                devices: roomDevices,
              );
              context.push(
                '/detail',
                extra: detailContent,
              );
            },
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0),
          child: SizedBox(
            height: Consts.deviceWidgetHeight,
            child: ListView.builder(
              itemCount: roomDevices.length,
              scrollDirection: Axis.horizontal,
              shrinkWrap: true,
              itemBuilder: (BuildContext context, int index) {
                final isFirst = roomDevices[index] == roomDevices.first;
                final isLast = roomDevices[index] == roomDevices.last;
                return Padding(
                  padding: isLast
                      ? const EdgeInsets.only(left: 8.0, right: 16)
                      : EdgeInsets.only(left: isFirst ? 16 : 8.0),
                  child: DeviceWidget(
                    device: roomDevices[index],
                  ),
                );
              },
            ),
          ),
        ),
      ],
    );
  }
}
